<?php
/**
 * Display controls (as themes decoration)
 *
 * @todo ? m/b move to GenericControls.template.php
 *
 * @author MaestroSite.ru <smf2@maestrosite.ru>
 * @version 0.2
 */

/**
 * Single-sitrings helpers
 *
 * @api
 * @version 0.2
 */
class GenericControls
{
	/**
	 * Catalog title
	 */
	public static function cat_bar( $label )
	{
		echo '<div class="cat_bar"><h3 class="catbg">', $label, '</h3></div>';
	}
	/**
	 * Simple title
	 */
	public static function title_bar( $label )
	{
		echo '<div class="title_bar"><h3 class="titlebg">', $label, '</h3></div>';
	}
	/**
	 * Information center title
	 */
	public static function title_ic( $label )
	{
		echo '<div class="title_barIC"><h4 class="titlebg">', $label, '</h4></div>';
	}
	/**
	 * Button "submit"
	 */
	public static function button_submit( $label = null )
	{
		global $txt, $context;
		echo '<input type="submit" class="button_submit" accesskey="s" tabindex="', $context['tabindex']++,
			'" name="save" value="', $label ? $label : (empty($txt['save']) ? 'save' : $txt['save']), '" />';
	}
	/**
	 * Button "preview"
	 */
	public static function button_preview( $label = null )
	{
		global $txt, $context;
		echo '<input type="submit" class="button_submit" accesskey="p" tabindex="', $context['tabindex']++,
			'" name="preview" value="', $label ? $label : (empty($txt['preview']) ? 'preview' : $txt['preview']), '" />';
	}
	/**
	 * Form header with session vars and sequence number fields
	 */
	public static function form_header( $action, $method = 'post', $id = null, $name = null )
	{
		global $context;

		echo '<form action="', $action, '" method="' , $method , '" accept-charset="', $context['character_set'];
		if( $id )
			echo '" id="', $id;
		if( $name )
			echo '" name="', $name;
		echo '">
			<input type="hidden" name="', $context['session_var'], '" value="', $context['session_id'], '" />';

		if( !empty($context['form_sequence_number']) )
			echo '
			<input type="hidden" name="seqnum" value="', $context['form_sequence_number'], '" />';
	}
	/**
	 * Form footer with submit button
	 */
	public static function form_footer( $submit = null, $reset = null )
	{
		self::button_submit($submit);
		echo '</form>';
	}
	/**
	 * Boards select
	 *
	 * $boards = array(
		[id_cat] = array(
			[id], [name], [boards] => array(
				array([id], [name], [child_level], [seleted]),
				...
			),
		),
		...
	 * );
	 * @see /Sources/Subs-MessageIndex.php Detail boards list format
	 *
	 * @param array $boards array of displayed boards
	 * @param string $name select element name
	 */
	public static function boards_select( array $boards = null, $name = 'move_to' )
	{
		if( empty( $boards ) )
			return;

		global $smcFunc;

		echo '<select name="', $name, '">';
		foreach( $boards as $cat )
		{
			echo '<optgroup label="', $smcFunc['htmlspecialchars']($cat['name'], ENT_QUOTES), '">';
			foreach( $cat['boards'] as $board )
			{
				echo '<option value="', $board['id'], '">';
				if( $board['child_level'] )
					echo  str_repeat('==', $board['child_level'] - 1) , '=&gt;';
				echo $smcFunc['htmlspecialchars']($board['name'], ENT_QUOTES), '</option>';
			}
			echo '</optgroup>';
		}
		echo '</select> ';
	}
	/**
	 * Boards definition list (class="settings")
	 *
	 * $boards = array(
		[id_cat] = array(
			[id], [name], [boards] => array(
				array([id], [name], [child_level], [seleted]),
				...
			),
		),
		...
	 * );
	 * @see /Sources/Subs-MessageIndex.php Detail boards list format
	 *
	 * @param array $boards array of displayed boards
	 * @param callback $callback detail info function
	 */
	public static function boards_list( array $boards, $callback = null )
	{
		if( empty( $boards ) )
			return;

		global $scripturl, $smcFunc;
			echo '<fieldset>';
			echo '<dl class="settings">';
			foreach( $boards as $cat )
			{
				echo '<dt>', $smcFunc['htmlspecialchars']($cat['name']), '</dt><dd>';
				foreach( $cat['boards'] as $board )
				{
					echo '<div>';//, $board['id'], ' ';
					if( $board['child_level'] )
						echo  str_repeat('==', $board['child_level'] - 1) , '=&gt;';
					echo '<a href="', $scripturl, '?board=', $board['id'], '.0">', 
						$smcFunc['htmlspecialchars']($board['name'], ENT_QUOTES), '</a>';
					$callback && $callback( $board );
					echo '</div>';
				}
				echo '</dd>';
			}
			echo '</dl>';
			echo '</fieldset>';
	}
}

/**
 * Layout functions
 *
 * Example use:
 * 1. Display "roundframe" block:
 * 	$context['templates_layers'][] = 'roundframe';
 *
 * 2. Display "windowbg2" block with title 'Mega Title, Super Bar!' and slice:
 * 	$context['title_bar_label'] = 'Mega Title, Super Bar!';
 * 	$context['template_layers'][] = 'title_bar';
 * 	$context['template_layers'][] = 'windowbg2_content';
 */

/**
 * Roundframe division
 */
function template_roundframe_above()
{
	echo '<span class="upperframe"><span></span></span><div class="roundframe">';
}
function template_roundframe_below()
{
	echo '</div><span class="lowerframe"><span></span></span>';
}

/**
 * Content (slice) division
 */
function template_content_above()
{
	echo '<span class="topslice"><span></span></span><div class="content">';
}
function template_content_below()
{
	echo '</div><span class="botslice"><span></span></span>';
}

/**
 * Windowbg content division
 */
function template_windowbg_content_above()
{
	echo '<div class="windowbg">';
	template_content_above();
}
function template_windowbg_content_below()
{
	template_content_below();
	echo '</div>';
}

/**
 * Windowbg2 content division
 */
function template_windowbg2_content_above()
{
	echo '<div class="windowbg2">';
	template_content_above();
}
function template_windowbg2_content_below()
{
	template_content_below();
	echo '</div>';
}

/**
 * Catalog title layout
 */
function template_cat_bar_above()
{
	global $context;
	GenericControls::cat_bar( $context['cat_bar_label'] );
}
function template_cat_bar_below()
{
}

/**
 * Simple title layout
 */
function template_title_bar_above()
{
	global $context;
	GenericControls::title_bar( $context['title_bar_label'] );
}
function template_title_bar_below()
{
}

/**
 * Form layout
 */
function template_form_above()
{
	global $context;
	GenericControls::form_header(empty($context['form']['action']) ? '?' : $context['form']['action'] );
}
function template_form_below()
{
	GenericControls::form_footer();
}
